import { assert } from 'chai'
import { FakeAxios } from '../testhelpers.js'
import { createProcessRedirect } from '@/helpers'
import axios from 'axios'

import store from '../store/index.spec.js'
import sinon from 'sinon'

describe('helpers/process', () => {
  let mock

  before('Setting up mocks', () => {
    mock = new FakeAxios(axios)
  })

  describe('createProcessRedirect', () => {
    const router = {}

    beforeEach(() => {
      router.push = sinon.spy()
    })

    afterEach(() => {
      mock.reset()
      store.reset()
    })

    it('creates a process and redirects', async () => {
      mock.onPost('/process/corpus/').reply(201, { id: 'processid' })
      await createProcessRedirect(store, router, { corpus: 'corpusid', element: 'elementid' })

      assert.strictEqual(mock.history.all.length, 1)
      assert.deepStrictEqual(store.state.process.processes.processid, { id: 'processid', _complete: false })
      assert.ok(router.push.calledOnce)
      assert.ok(router.push.calledWith({ name: 'process-filter', params: { id: 'processid' } }))
    })

    it('notifies on failure', async () => {
      const payload = {
        corpus: 'corpusid',
        element: 'elementid',
        element_name_contains: 'A',
        element_type: 'alphanumeric'
      }
      mock.onPost('/process/corpus/').reply(518, { detail: "I'm a teapot" })
      await createProcessRedirect(store, router, payload)

      assert.strictEqual(mock.history.all.length, 1)
      assert.deepStrictEqual(store.history, [
        {
          action: 'process/createProcess',
          payload: {
            corpus: 'corpusid',
            element: 'elementid',
            element_name_contains: 'A',
            element_type: 'alphanumeric'
          }
        },
        {
          mutation: 'notifications/notify',
          payload: {
            text: "An error occurred creating the process: I'm a teapot",
            type: 'error'
          }
        }
      ])
      assert.strictEqual(router.push.calledOnce, false)
    })
  })
})
